@@ -1,15 +1,15 @@
-#!/bin/sh
+#!/bin/sh -x
 
 VERSION=$2
-XPI=$3
+TAR=$3
 PACKAGE=$(dpkg-parsechangelog | sed -n 's/^Source: //p')
-TAR=../${PACKAGE}_${VERSION}.orig.tar.gz
 DIR=../${PACKAGE}-${VERSION}
 
-/usr/bin/xpi-unpack $XPI $DIR
-
+mkdir $DIR
+tar -zxf $TAR -C $DIR
 tar -zcf ../${PACKAGE}_${VERSION}+dfsg.orig.tar.gz --exclude *.exe $DIR
 
 rm -rf $DIR
-rm $XPI
+rm $TAR
+
 
